LightWave2D
===========

|python|
|docs|
|PyPi|
|PyPi_download|


..  figure:: https://github.com/MartinPdeS/LightWave2D/blob/master/docs/images/resonator.gif?raw=true
   :alt: some image
   :class: with-shadow float-left
   :width: 800px

..  figure:: https://github.com/MartinPdeS/LightWave2D/blob/master/docs/images/sphere_scattering.gif?raw=true
   :alt: some image
   :class: with-shadow float-left
   :width: 800px


This is a package for 2D FDTD.



----

Contact Information
*******************

As of 2023 the project is still under development if you want to collaborate it would be a pleasure. I encourage you to contact me.

LightWave2D was written by `Martin Poinsinet de Sivry-Houle <https://github.com/MartinPdS>`_  .

Email:`martin.poinsinet-de-sivry@polymtl.ca <mailto:martin.poinsinet-de-sivry@polymtl.ca?subject=LightWave2D>`_ .

.. |python| image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
   :target: https://www.python.org/

.. |docs| image:: https://readthedocs.org/projects/lightwave2d/badge/?version=latest
   :target: https://lightwave2d.readthedocs.io/en/latest/
   :alt: Documentation Status

.. |PyPi| image:: https://badge.fury.io/py/LightWave2D.svg
   :target: https://pypi.org/project/LightWave2D/

.. |PyPi_download| image:: https://img.shields.io/pypi/dm/lightwave2d.svg
   :target: https://pypistats.org/packages/lightwave2d